@@ -51,7 +51,7 @@ enum
 + (NSString *)archiveType;
 
 + (void)registerFileExtension:(NSString *)extension forArchiveClass:(Class)clazz;
-+ (NSDictionary *)classForFileExtension:(NSString *)fileExtension;
++ (Class)classForFileExtension:(NSString *)fileExtension;
 + (NSArray *)allFileExtensions;
 
 @end
